"""Add indexes.partition

Revision ID: cbd03c81a699
Revises: 654bfd77afe4
Create Date: 2019-02-20 21:41:32.535123

"""
from alembic import op
import sqlalchemy as sa
from index_registry.utils.index_field_helpers import properties_from_key


# revision identifiers, used by Alembic.
from index_registry.sql.models import Index

revision = 'cbd03c81a699'
down_revision = '654bfd77afe4'
branch_labels = None
depends_on = None


def upgrade():
    op.add_column('indexes', sa.Column('partition', sa.String(), nullable=True))

    conn = op.get_bind()
    for result in conn.execute("SELECT index_path FROM indexes"):
        index_path = result['index_path']

        props = properties_from_key(index_path)

        update_stmt = Index.__table__.update().values({"partition": props['partition']}) \
            .where(Index.index_path == index_path)

        conn.execute(update_stmt)

    op.drop_constraint('leases_index_path_fkey1', 'leases', type_='foreignkey')
    op.create_foreign_key(None, 'searchers', 'indexes', ['index_path'], ['index_path'], ondelete='CASCADE')


def downgrade():  # pragma: no cover
    op.drop_constraint(None, 'searchers', type_='foreignkey')
    op.create_foreign_key('leases_index_path_fkey1', 'leases', 'indexes', ['index_path'], ['index_path'])
    op.drop_column('indexes', 'partition')
