from functools import wraps
import logging
from pscr_common.log import setup_lambda_logging

from index_registry.utils.config import Config

_logger = logging.getLogger(__name__)
config = Config.create()


def setup_lambda_handler(f):
    @wraps(f)
    def wrapper(event, context):
        try:
            setup_lambda_logging(level=config.get("log", "level", fallback="INFO"),
                                 svc_version=config.get("service", "version"),
                                 env_id=config.get("env", "id"),
                                 svc_id=context.aws_request_id)

            _logger.debug("Event: %s", event)

            if event.get('route') == 'version':
                return {'version': config.get('service', 'version')}

            return f(event, context, config)
        except Exception:
            _logger.exception("Error during lambda handler")
            raise

    return wrapper
