import json
import logging
from datetime import datetime

from pscr_common.aws import get_boto3_resource

from index_registry.engine.stats_engine import StatsEngine, JSONEncoder
from index_registry.lambda_handler import setup_lambda_handler

_logger = logging.getLogger(__name__)


@setup_lambda_handler
def handler(event, _context, config):
    sync_stats(config)


def sync_stats(config):
    s3 = get_boto3_resource('s3')
    s3_bucket_name = config.get('stats', 's3_bucket_name')

    engine = StatsEngine(config)

    # Create the stats object
    stats = engine.create_stats()

    # Report metrics (if feature flag is on)
    engine.report_org_metrics(stats, config)

    # Assemble the stats for s3 and convert it to json
    data_for_s3 = json.dumps(stats, cls=JSONEncoder)

    # Create s3 object and upload it in the stats bucket
    response_archive = s3.Object(s3_bucket_name, s3_bucket_name + datetime.now().strftime("%Y/%m/%d/%H:%M:%S") + '.json').put(
        Body=data_for_s3).get('ResponseMetadata')
    response_latest = s3.Object(s3_bucket_name, 'stats.json').put(
        Body=data_for_s3).get('ResponseMetadata')

    if response_archive.get('HTTPStatusCode') != 200 or response_latest.get('HTTPStatusCode') != 200:
        _logger.error("Error when uploading the stats to the s3 bucket")
        raise Exception("Error when uploading the stats to the s3 bucket")

    _logger.info("Successfully aggregated dynamodb stats table statistics to the s3 bucket")
