import logging
from typing import Optional, List
from pydantic import BaseModel, RootModel, Field

from pscr_common.utils import get_utcnow_with_tzinfo, datetime_to_ms_timestamp


_logger = logging.getLogger(__name__)


def now_ms():
    return datetime_to_ms_timestamp(get_utcnow_with_tzinfo(truncate_to_ms=True))


class QueryEntry(BaseModel):
    org_key: str
    consumer_name: str
    index_path: str
    index_hash: str
    max_backend_timestamp: int
    min_backend_timestamp: int
    max_device_timestamp: int
    min_device_timestamp: int
    document_count: int
    type: str
    timestamp: Optional[int] = Field(default_factory=now_ms)
    container_id: Optional[str] = "UNKNOWN"


class QueryEntries(RootModel):
    root: List[QueryEntry]
